@@ -1,4 +1,4 @@
-from typing import Dict, Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 
 import attr
 
@@ -28,6 +28,7 @@ class PlanConfig:
     auth_config: AuthConfig = attr.ib(kw_only=True)
     headers: Dict[str, str] = attr.ib(kw_only=True, factory=dict)
     env_file_path: Optional[str] = attr.ib(kw_only=True, default=None)
+    module_specific_config: Dict[str, Any] = attr.ib(kw_only=True, factory=dict)
     # Current config version
     version = CONFIG_VERSION
 
