@@ -10,9 +10,12 @@ class Status(Enum):
     failure = "failure"
     error = "error"
 
+    def __str__(self) -> str:
+        return self.value
+
     def __add__(self, other: Status) -> Status:
         """Failure > Error > Success."""
-        if self == Status.error:
+        if self == Status.error or other == Status.error:
             return Status.error
 
         if self == Status.failure or other == Status.failure:
